package com.greenorange.promotion.model.dto.projectSettlement;

import io.swagger.v3.oas.annotations.media.Schema;
import jakarta.validation.constraints.NotBlank;
import jakarta.validation.constraints.Min;
import lombok.Data;

import java.io.Serial;
import java.io.Serializable;
import java.math.BigDecimal;
import java.time.LocalDateTime;
import java.util.Date;

import com.greenorange.promotion.common.PageRequest;

/**
 * 项目结算记录查询请求体，继承自分页请求 PageRequest
 */
@Data
@Schema(description = "项目结算记录查询请求体", requiredProperties = {"current", "pageSize"})
public class ProjectSettlementQueryRequest extends PageRequest implements Serializable {

    /**
     * 结算记录ID
     */
    @Min(value = 1L, message = "结算记录ID ID不能小于1")
    @Schema(description = "结算记录ID", example = "1")
    private Long id;

    /**
     * 项目明细名称
     */
    @Schema(description = "项目明细名称", example = "新用户完成首单")
    private String projectDetailName;

    /**
     * 结算数量
     */
    @Schema(description = "结算数量", example = "2")
    private Integer settlementQuantity;

    /**
     * 结算收益
     */
    @Schema(description = "结算收益", example = "2.34")
    private BigDecimal settlementRevenue;

    /**
     * 作业时间
     */
    @Schema(description = "作业时间", example = "2025-05-10")
    private String workTime;

    /**
     * 结算时间
     */
    @Schema(description = "结算时间", example = "2025-05-12")
    private String settlementTime;

    /**
     * 推广码申请记录id
     */
    @Min(value = 1L, message = "推广码申请记录id ID不能小于1")
    @Schema(description = "推广码申请记录id", example = "1")
    private Long promoCodeApplyId;

    /**
     * 项目id
     */
    @Min(value = 1L, message = "项目id ID不能小于1")
    @Schema(description = "项目id", example = "1")
    private Long projectId;

    /**
     * 项目明细id
     */
    @Min(value = 1L, message = "项目明细id ID不能小于1")
    @Schema(description = "项目明细", example = "1")
    private Long projectDetailId;


    @Serial
    private static final long serialVersionUID = 1L;
}

