package com.greenorange.promotion.model.dto.promoCodeApply;

import io.swagger.v3.oas.annotations.media.Schema;
import jakarta.validation.constraints.NotBlank;
import jakarta.validation.constraints.Min;
import lombok.Data;
import java.math.BigDecimal;

import java.io.Serial;
import java.io.Serializable;

/**
 * 推广码申请记录更新请求体
 */
@Data
@Schema(description = "推广码申请记录更新请求体", requiredProperties = {
                "id",
                "salespersonName",
                "salespersonPhone",
                "promoCodeInfoKey",
                "promoCodeLink",
                "projectId",
                "projectName",
                "projectImage",
                "userId",
                "promoCodeImage"
})
public class PromoCodeApplyUpdateRequest implements Serializable {

    /**
     * 推广码申请ID
     */
    @Min(value = 1L, message = "推广码申请ID ID不能小于1")
    @Schema(description = "推广码申请ID", example = "1")
    private Long id;

    /**
     * 业务员姓名
     */
    @NotBlank(message = "业务员姓名不能为空")
    @Schema(description = "业务员姓名", example = "chenxinzhi")
    private String salespersonName;

    /**
     * 业务员手机号
     */
    @NotBlank(message = "业务员手机号不能为空")
    @Schema(description = "业务员手机号", example = "15888610253")
    private String salespersonPhone;

    /**
     * 绑定的推广码信息key
     */
    @NotBlank(message = "绑定的推广码信息key不能为空")
    @Schema(description = "绑定的推广码信息key", example = "ykxy227")
    private String promoCodeInfoKey;

    /**
     * 绑定的推广码链接
     */
    @NotBlank(message = "绑定的推广码链接不能为空")
    @Schema(description = "绑定的推广码链接", example = "mp://y04CZgGkCBmIaZd")
    private String promoCodeLink;

    /**
     * 推广码图片
     */
    @NotBlank(message = "推广码图片不能为空")
    @Schema(description = "推广码图片", example = "http://xxx.png")
    private String promoCodeImage;

    /**
     * 绑定的项目ID
     */
    @Min(value = 1L, message = "用户ID ID不能小于1")
    @Schema(description = "绑定的项目ID", example = "1")
    private Long projectId;

    /**
     * 绑定的项目名称
     */
    @NotBlank(message = "绑定的项目名称不能为空")
    @Schema(description = "绑定的项目名称", example = "美团省钱包")
    private String projectName;

    /**
     * 绑定的项目图片URL
     */
    @NotBlank(message = "绑定的项目图片URL不能为空")
    @Schema(description = "绑定的项目图片URL", example = "3E8U2AM8")
    private String projectImage;

    /**
     * 用户ID
     */
    @Min(value = 1L, message = "用户ID ID不能小于1")
    @Schema(description = "用户ID", example = "1")
    private Long userId;


    @Serial
    private static final long serialVersionUID = 1L;
}